@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007, 2008 David Shaw <dshaw@jabberwocky.com>
+ * Copyright (C) 2007, 2008, 2009 David Shaw <dshaw@jabberwocky.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
-static const char RCSID[]="$Id: paperkey.c 356 2008-01-31 14:03:58Z dshaw $";
+static const char RCSID[]="$Id: paperkey.c 579 2009-01-28 03:28:01Z dshaw $";
 
 #include <config.h>
 #include <stdio.h>
@@ -23,6 +23,10 @@ static const char RCSID[]="$Id: paperkey.c 356 2008-01-31 14:03:58Z dshaw $";
 #include <stdlib.h>
 #include <string.h>
 #include <errno.h>
+#ifdef _WIN32
+#include <io.h>
+#include <fcntl.h>
+#endif
 #include "output.h"
 #include "extract.h"
 #include "restore.h"
@@ -97,6 +101,15 @@ main(int argc,char *argv[])
   enum data_type output_type=BASE16;
   enum data_type input_type=AUTO;
 
+#ifdef _WIN32
+  if(_setmode(_fileno(stdin),_O_BINARY)==-1)
+    {
+      fprintf(stderr,"Unable to set stdin mode to binary: %s\n",
+	      strerror(errno));
+      exit(1);
+    }
+#endif
+
   secret_key=secrets=stdin;
 
   while((arg=getopt_long(argc,argv,"hVv",long_options,NULL))!=-1)
@@ -110,8 +123,8 @@ main(int argc,char *argv[])
 
       case OPT_VERSION:
       case 'V':
-	printf("paperkey " VERSION "\n");
-	printf("Copyright (C) 2007, 2008 David Shaw\n");
+	printf("%s\n",PACKAGE_STRING);
+	printf("%s\n",COPYRIGHT_STRING);
 	printf("This is free software.  You may redistribute copies of it"
 	       " under the terms of\n");
 	printf("the GNU General Public License"
